/**
 * GISViewerESRI.java Shapefile Viewer version 0.2
 * Neil Moomey, www.neilmoomey.com
 * This GIS Viewer uses ESRI's Map Objects for Java library.
 * ESRI has a 60 day demo you can order at http://www.esri.com/software/mojava/index.html
 **/


import javax.swing.*;
import java.awt.*;
import java.net.*;
import java.io.*;

class GISViewerPane extends javax.swing.JPanel {
  private com.esri.mo.ui.bean.Map map;
  private com.esri.mo.ui.bean.Layer lyr;
  private javax.swing.JToolBar toolbar;
  private java.awt.Toolkit tk ;

  public GISViewerPane(String filenames[]) {
    map = new com.esri.mo.ui.bean.Map();
    toolbar = new javax.swing.JToolBar();
    tk = java.awt.Toolkit.getDefaultToolkit();
    initializeToolBar();
    map.setBackground(new java.awt.Color(0x66ffff));
    setLayout(new java.awt.BorderLayout());
    add(map, java.awt.BorderLayout.CENTER);
    add(toolbar, java.awt.BorderLayout.NORTH);
    System.out.println("\n*************************************************************************\n");
    System.out.println("number of args = "+ filenames.length);

    for (int i=0; i<filenames.length; i++) {
	String filename = "0;" + filenames[i];
	lyr= new com.esri.mo.ui.bean.Layer();
	System.out.println("Please wait while I download data from " + filename + "\n");
	lyr.setDataset(filename);
	map.add(lyr);
    }
  }

  private void initializeToolBar() {
     // add map tools
     // There are several ways to do this. You can use your own icons like this:
	JButton zoom = new JButton(new ImageIcon("icons/zoom.gif"));
    zoom.setToolTipText("Zoom with right/left click");

    JButton bntzi  = new JButton(new ImageIcon("icons/zoomin.gif"));
    bntzi.setToolTipText("Zoom In");

    JButton bntzo  = new JButton(new ImageIcon("icons/zoomout.gif"));
    bntzo.setToolTipText("Zoom Out");

    JButton bntfzi = new JButton(new ImageIcon("icons/fzi.gif"));
    bntfzi.setToolTipText("Zoom in click");

    JButton bntfzo = new JButton(new ImageIcon("icons/fzo.gif"));
    bntfzo.setToolTipText("Zoom out click");

    JButton bntpan = new JButton(new ImageIcon("icons/pan.gif"));
    bntpan.setToolTipText("Pan");

	// Or you can use the icons in the esri_mo10res.jar file like this:
	JButton back2ex = new JButton(new ImageIcon(com.esri.mo.res.Res.class.getResource("ico/tb/back2ex.gif")));
    back2ex.setToolTipText("Back to Previous Extent");

    JButton fullview = new JButton(new ImageIcon("icons/fullextent.gif"));
    fullview.setToolTipText("Full View");

	//JButton identifier = new JButton(new ImageIcon(com.esri.mo.res.Res.class.getResource("ico/tb/identify.gif")));
    //identifier.setToolTipText("Indentify");

	JButton measuretool = new JButton(new ImageIcon(com.esri.mo.res.Res.class.getResource("ico/tb/meas_mi.gif")));
    measuretool.setToolTipText("Measure Tool in Miles");

	JButton print = new JButton(new ImageIcon(com.esri.mo.res.Res.class.getResource("ico/Print16c.gif")));
    print.setToolTipText("Print");

    //or you can include them in a jar like this I think:
    //new JButton(new ImageIcon(Resource.getIcon("icons/up.gif")));



    zoom.addActionListener(new java.awt.event.ActionListener() {
        public void actionPerformed(java.awt.event.ActionEvent e) {
			//System.out.println("zoom = "+e);
            com.esri.mo.ui.bean.ZoomZoom zz = new com.esri.mo.ui.bean.ZoomZoom();
            zz.setCursor(czz);
            map.setSelectedTool(zz);
        }
    });


    bntzi.addActionListener(new java.awt.event.ActionListener() {
        public void actionPerformed(java.awt.event.ActionEvent e) {
            com.esri.mo.ui.bean.ZoomIn zin = new com.esri.mo.ui.bean.ZoomIn();
            zin.setCursor(czi);
            map.setSelectedTool(zin);
        }
    });

    bntzo.addActionListener(new java.awt.event.ActionListener() {
        public void actionPerformed(java.awt.event.ActionEvent e) {
            com.esri.mo.ui.bean.ZoomOut zo =
                new com.esri.mo.ui.bean.ZoomOut();
            zo.setCursor(czo);
            map.setSelectedTool(zo);
        }
    });

    bntfzi.addActionListener(new java.awt.event.ActionListener() {
        public void actionPerformed(java.awt.event.ActionEvent e) {
            map.zoom(0.5);
        }
    });

    bntfzo.addActionListener(new java.awt.event.ActionListener() {
        public void actionPerformed(java.awt.event.ActionEvent e) {
            map.zoom(1.5);
        }
    });

    bntpan.addActionListener(new java.awt.event.ActionListener() {
        public void actionPerformed(java.awt.event.ActionEvent e) {
            com.esri.mo.ui.bean.Pan p = new com.esri.mo.ui.bean.Pan();
            p.setCursor(cpa);
            map.setSelectedTool(p);
        }
    });

	back2ex.addActionListener(new java.awt.event.ActionListener() {
     public void actionPerformed(java.awt.event.ActionEvent e) {
       map.setExtent(map.getPreviousExtent());
     	}
   });

	fullview.addActionListener(new java.awt.event.ActionListener() {
     public void actionPerformed(java.awt.event.ActionEvent e) {
       map.setExtent(map.getFullExtent());
     	}
   });

	/** identifier doesn't work because there is no TOC for selecting the layer first.  See tutorial Identify class.
	identifier.addActionListener(new java.awt.event.ActionListener() {
     public void actionPerformed(java.awt.event.ActionEvent e) {
       com.esri.mo.ui.bean.Identify identify = new com.esri.mo.ui.bean.Identify();
       map.setSelectedTool(identify);
     	}
   });
   */

	// The units don't seem correct to me.
	measuretool.addActionListener(new java.awt.event.ActionListener() {
     public void actionPerformed(java.awt.event.ActionEvent e) {
       com.esri.mo.ui.tool.MeasureTool measureTool = new com.esri.mo.ui.tool.MeasureTool();
       System.out.println("units = " + measureTool.getMeasureUnit()); // 3=feet, 4=miles, 5=meters, 6=kilometers
       map.setSelectedTool(measureTool);
     	}
   });

	print.addActionListener(new java.awt.event.ActionListener() {
     public void actionPerformed(java.awt.event.ActionEvent e) {
     com.esri.mo.ui.bean.Print mapPrint = new com.esri.mo.ui.bean.Print();
     mapPrint.setMap(map);
     mapPrint.doPrint();
     	}
   });

    toolbar.add(zoom);
    toolbar.add(bntzi);
    toolbar.add(bntzo);
    toolbar.add(bntfzi);
    toolbar.add(bntfzo);
    toolbar.add(bntpan);
    toolbar.add(back2ex);
    toolbar.add(fullview);
    //toolbar.add(identifier);
    toolbar.add(measuretool);
    toolbar.add(print);

  }

  // These are the smaller icons used for the cursor of each tool.

  ImageIcon icon_zzz = new ImageIcon("icons/zoom_cur.gif");
  Image zzz = icon_zzz.getImage();

  ImageIcon icon_zii = new ImageIcon("icons/zi_cur.gif");
  Image zii = icon_zii.getImage();

  ImageIcon icon_zoi = new ImageIcon("icons/zo_cur.gif");
  Image zoi = icon_zoi.getImage();

  ImageIcon icon_pai = new ImageIcon("icons/pan_cur.gif");
  Image pai = icon_pai.getImage();

  final java.awt.Cursor czz =
  java.awt.Toolkit.getDefaultToolkit().createCustomCursor(zzz,new java.awt.Point(8,8),"");

  final java.awt.Cursor czi =
  java.awt.Toolkit.getDefaultToolkit().createCustomCursor(zii,new java.awt.Point(8,8),"");

  final java.awt.Cursor czo =
  java.awt.Toolkit.getDefaultToolkit().createCustomCursor(zoi,new java.awt.Point(8,8),"");

  final java.awt.Cursor cpa =
  java.awt.Toolkit.getDefaultToolkit().createCustomCursor(pai ,new java.awt.Point(8,8),"");

}

